

capsuleer_lore_questions = [
    {
        'question': 'What was the name of the first capsuleer flown Titan class ship to be destroyed?',
        'answer': 'Steve',
        'wrong_answers': [
            'Steven',
            'Andie',
            'Scott',
            'Cyvok\'s Avatar',
        ]
    },
    {
        'question': 'How many Imperial Apocalypse Battleships were given out in the YC105 (2003) Amarr championship?',
        'answer': '5',
        'wrong_answers': [
            '3',
            '7',
            '9',
            '10',
        ]
    },
    {
        'question': 'What was the original name for the Band of Brothers (BoB) alliance?',
        'answer': 'Cookies, Cake, Cream and Pie (CCCP)',
        'wrong_answers': [
            'Cult of War (COW)',
            'Ascendant Frontier (ASCN)',
            'KenZoku (RKZ)',
            'Imperial Republic of the North (IRON)',
        ]
    },
    {
        'question': 'The Adrestia and Utu were awarded as prizes for which Alliance Tournament?',
        'answer': 'AT VIII',
        'wrong_answers': [
            'AT I',
            'AT II',
            'AT III',
            'AT IV',
            'AT V',
            'AT VI',
            'AT VII',
            'AT IX',
            'AT X',
            'AT XI',
            'AT XII',
        ]
    },
    {
        'question': 'The Vangel and Malice were awarded as prizes for which Alliance Tournament?',
        'answer': 'AT IX',
        'wrong_answers': [
            'AT I',
            'AT II',
            'AT III',
            'AT IV',
            'AT V',
            'AT VI',
            'AT VII',
            'AT VIII',
            'AT X',
            'AT XI',
            'AT XII',
        ]
    },
    {
        'question': 'The Etana and Cambion were awarded as prizes for which Alliance Tournament?',
        'answer': 'AT X',
        'wrong_answers': [
            'AT I',
            'AT II',
            'AT III',
            'AT IV',
            'AT V',
            'AT VI',
            'AT VII',
            'AT VIII',
            'AT IX',
            'AT XI',
            'AT XII',
        ]
    },
    {
        'question': 'The Moracha and Chremoas were awarded as prizes for which Alliance Tournament?',
        'answer': 'AT XI',
        'wrong_answers': [
            'AT I',
            'AT II',
            'AT III',
            'AT IV',
            'AT V',
            'AT VI',
            'AT VII',
            'AT VIII',
            'AT IX',
            'AT X',
            'AT XII',
        ]
    },
    {
        'question': 'The Whiptail and Chameleon were awarded as prizes for which Alliance Tournament?',
        'answer': 'AT XII',
        'wrong_answers': [
            'AT I',
            'AT II',
            'AT III',
            'AT IV',
            'AT V',
            'AT VI',
            'AT VII',
            'AT VIII',
            'AT IX',
            'AT X',
            'AT XI',
        ]
    },
    {
        'question': 'Who won Alliance Tournament I?',
        'answer': 'Band of Brothers',
        'wrong_answers': [
            'Agony Empire',
            'Ev0ke',
            'Hun Reloaded',
            'Hydra Reloaded',
            'Outbreak',
            'Pandemic Legion',
            'Suddenly Spaceships.',
            'Verge of Collapse',
            'The Camel Empire',
            'Pandemic Empire',
            'Legion of Brothers',
        ]
    },
    {
        'question': 'Who won Alliance Tournament II?',
        'answer': 'Band of Brothers',
        'wrong_answers': [
            'Agony Empire',
            'Ev0ke',
            'Hun Reloaded',
            'Hydra Reloaded',
            'Outbreak',
            'Pandemic Legion',
            'Suddenly Spaceships.',
            'Verge of Collapse',
            'The Camel Empire',
        ]
    },
    {
        'question': 'Who won Alliance Tournament III?',
        'answer': 'Band of Brothers',
        'wrong_answers': [
            'Agony Empire',
            'Ev0ke',
            'Hun Reloaded',
            'Hydra Reloaded',
            'Outbreak',
            'Pandemic Legion',
            'Suddenly Spaceships.',
            'Verge of Collapse',
            'The Camel Empire',
        ]
    },
    {
        'question': 'Who won Alliance Tournament IV?',
        'answer': 'Hun Reloaded',
        'wrong_answers': [
            'Agony Empire',
            'Band of Brothers',
            'Ev0ke',
            'Hydra Reloaded',
            'Outbreak',
            'Pandemic Legion',
            'Suddenly Spaceships.',
            'Verge of Collapse',
            'The Camel Empire',
        ]
    },
    {
        'question': 'Who won Alliance Tournament V?',
        'answer': 'Ev0ke',
        'wrong_answers': [
            'Agony Empire',
            'Band of Brothers',
            'Hun Reloaded',
            'Hydra Reloaded',
            'Outbreak',
            'Pandemic Legion',
            'Suddenly Spaceships.',
            'Verge of Collapse',
            'The Camel Empire',
        ]
    },
    {
        'question': 'Who won Alliance Tournament VI?',
        'answer': 'Pandemic Legion',
        'wrong_answers': [
            'Agony Empire',
            'Band of Brothers',
            'Ev0ke',
            'Hun Reloaded',
            'Hydra Reloaded',
            'Outbreak',
            'Suddenly Spaceships.',
            'Verge of Collapse',
            'The Camel Empire',
        ]
    },
    {
        'question': 'Who won Alliance Tournament VII?',
        'answer': 'Pandemic Legion',
        'wrong_answers': [
            'Agony Empire',
            'Band of Brothers',
            'Ev0ke',
            'Hun Reloaded',
            'Hydra Reloaded',
            'Outbreak',
            'Suddenly Spaceships.',
            'Verge of Collapse',
            'The Camel Empire',
        ]
    },
    {
        'question': 'Who won Alliance Tournament VIII?',
        'answer': 'Pandemic Legion',
        'wrong_answers': [
            'Agony Empire',
            'Band of Brothers',
            'Ev0ke',
            'Hun Reloaded',
            'Hydra Reloaded',
            'Outbreak',
            'Suddenly Spaceships.',
            'Verge of Collapse',
            'The Camel Empire',
        ]
    },
    {
        'question': 'Who won Alliance Tournament IX?',
        'answer': 'Hydra Reloaded',
        'wrong_answers': [
            'Agony Empire',
            'Band of Brothers',
            'Ev0ke',
            'Hun Reloaded',
            'Outbreak',
            'Pandemic Legion',
            'Suddenly Spaceships.',
            'Verge of Collapse',
            'The Camel Empire',
        ]
    },
    {
        'question': 'Who won Alliance Tournament X?',
        'answer': 'Verge of Collapse',
        'wrong_answers': [
            'Agony Empire',
            'Band of Brothers',
            'Ev0ke',
            'Hun Reloaded',
            'Hydra Reloaded',
            'Outbreak',
            'Pandemic Legion',
            'Suddenly Spaceships.',
            'The Camel Empire',
        ]
    },
    {
        'question': 'Who won Alliance Tournament XI?',
        'answer': 'Pandemic Legion',
        'wrong_answers': [
            'Agony Empire',
            'Band of Brothers',
            'Ev0ke',
            'Hun Reloaded',
            'Hydra Reloaded',
            'Outbreak',
            'Suddenly Spaceships.',
            'Verge of Collapse',
            'The Camel Empire',
        ]
    },
    {
        'question': 'Who won Alliance Tournament XII?',
        'answer': 'The Camel Empire',
        'wrong_answers': [
            'Agony Empire',
            'Band of Brothers',
            'Ev0ke',
            'Hun Reloaded',
            'Hydra Reloaded',
            'Outbreak',
            'Pandemic Legion',
            'Suddenly Spaceships.',
            'Verge of Collapse',
        ]
    },
    {
        'question': 'Who got banned from all future Alliance Tournaments in AT XII?',
        'answer': 'CODE.',
        'wrong_answers': [
            'Agony Empire',
            'Band of Brothers',
            'Ev0ke',
            'Hun Reloaded',
            'Hydra Reloaded',
            'Outbreak',
            'Pandemic Legion',
            'Suddenly Spaceships.',
            'Verge of Collapse',
            'James 315 Official Fan Club',
        ]
    },
]


npc_lore_questions = [
    {
        'question': 'Who wrote Pax Amarria?',
        'answer': 'Heideran VII',
        'wrong_answers': [
            'Jamyl I',
            'Zaragram II',
            'Damius III',
            'Souro Foiritan',
        ]
    },
    {
        'question': 'Who was the Ray of Matar?',
        'answer': 'Karin Midular',
        'wrong_answers': [
            'Maleatu Shakor',
            'Abja Etbald',
            'Akassa Midular',
            'Ana Utulf',
        ]
    },
    {
        'question': 'What was the Khumaak named after?',
        'answer': 'A person',
        'wrong_answers': [
            'A relic',
            'A ship',
            'A planet',
            'An animal',
        ]
    },
    {
        'question': 'Itzak Barah is...',
        'answer': '... a poet',
        'wrong_answers': [
            '... a soldier',
            '... a priest',
            '... a politician',
            '... a businessman',
        ]
    },
    {
        'question': 'What work did Dr. Adad do?',
        'answer': 'Entertain children',
        'wrong_answers': [
            'Create insorum',
            'Develop cloaking technology',
            'Study sleepers and wormholes',
            'Teach at a university',
        ]
    },
    {
        'question': 'What Caldari political bloc does the Sukuuvestaa megacorp belong to?',
        'answer': 'Practicals',
        'wrong_answers': [
            'Liberals',
            'Profiteers',
            'Draconians',
            'Patriots',
        ]
    },
    {
        'question': 'In what year did the Caldari-Gallente war end?',
        'answer': 'YC 12',
        'wrong_answers': [
            'YC 0',
            'YC 15',
            'YC 50',
            'AD 23148',
        ]
    },
    {
        'question': 'In what year was Concord established?',
        'answer': 'AD 23233',
        'wrong_answers': [
            'YC 0',
            'YC 1',
            'AD 21251',
            'AD 23216',
        ]
    },
    {
        'question': 'In what year AD was New Eden Standard Time introduced?',
        'answer': 'AD 23236',
        'wrong_answers': [
            'AD 21251',
            'AD 23216',
            'YC 1',
            'YC 5',
        ]
    },
]

#############################
# Easy copy and paste formats
#############################
_ignore_me = [
    {
        'question': '',
        'answer': '',
        'wrong_answers': [
            '',
            '',
            '',
            '',
        ]
    },
]
